@@ -197,14 +197,14 @@ def slugify(s):
 
 
 def map_github_action(config):
-    config['ci_commit_ref_name'] = config.get('github_ref_name')
+    config['ci_commit_ref_name'] = config.get('github_head_ref') or config.get('github_ref_name')
     config['ci_job_id'] = config.get('github_run_id')
     config['ci_pipeline_id'] = config.get('github_run_number')
     config['ci_project_name'] = config.get('customer')
     repos = config.get('github_repository', '').split('/')
     if len(repos) > 1:
         config['ci_project_name'] = repos[1]
-    config['ci_commit_ref_slug'] = slugify(config.get('github_ref_name'))
+    config['ci_commit_ref_slug'] = slugify(config.get('github_head_ref') or config.get('github_ref_name'))
     config['ci_repository_url'] = net.urljoin(config.get('github_server_url'), config.get('github_repository'))
     config['ci_commit_sha'] = config.get('github_sha')
     config['ci_project_namespace'] = config.get('github_repository_owner')
