@@ -1,4 +1,5 @@
 import logging
+import sys
 from os import environ, path, walk
 import paramiko
 from sys import exit
@@ -15,15 +16,22 @@ def get_values():
     res = {
         'username': 'coverage',
         'password': environ.get('COVERAGE_PASS'),
+        'server': environ.get('COVERAGE_SERVER', 'coverage.vauxoo.com'),
+        'port': environ.get('COVERAGE_PORT', '8451'),
         'commit_slug': environ.get('CI_COMMIT_REF_SLUG'),
         'project_name': environ.get('CI_PROJECT_NAME')
     }
     return res
 
 
-def get_sftp_client(username, password):
+def get_sftp_client(username, password, host, port):
     _logger.info('Connecting to the remote host')
-    transport = paramiko.Transport(('coverage.vauxoo.com', 8451))
+    try:
+        p = int(port)
+    except ValueError as err:
+        _logger.error('Failed to parse the port number "%s" with: %s', port, err)
+        sys.exit(1)
+    transport = paramiko.Transport((host, p))
     transport.connect(username=username,
                       password=password)
     return paramiko.SFTPClient.from_transport(transport)
@@ -49,7 +57,7 @@ def push_files():
         return False
 
     _logger.info('Pushing files from: %s', src_path)
-    sftp = get_sftp_client(values.get('username'), values.get('password'))
+    sftp = get_sftp_client(values.get('username'), values.get('password'), values.get('server'), values.get('port'))
     for root, dirs, files in walk(src_path):
         _logger.debug('Root: %s .. Dirs: %s .. Files: %s', root, dirs, files)
         remote = path.join(path.relpath(root, src_path), remote_path)
@@ -70,7 +78,7 @@ def push_files():
 def show_url():
     values = get_values()
     print("Coverage report can be found in:")
-    print("https://coverage.vauxoo.com/{}-{}".format(values.get('commit_slug'), values.get('project_name')))
+    print("https://{}/{}-{}".format(values.get('server'), values.get('commit_slug'), values.get('project_name')))
 
 
 def push_coverage_result():
